```{include} ../../README.md
```

```{toctree}
:hidden:
Home <self>
installation
```

```{toctree}
:hidden:
:caption: User Guide
introduction
linear
ensemble
predict
imbalance
bandwidth_search
network_graph
sklearn_compatibility
mgwr_comparison
references
```

```{toctree}
:hidden:
:caption: API
api
```

```{toctree}
:hidden:
:caption: For contributors
contributing
GitHub <https://github.com/uscuni/gwlearn>
Changelog <https://github.com/uscuni/gwlearn/releases>

```

